@@ -32,6 +32,7 @@ use v5.10;
 
 use File::Basename qw(basename);
 use List::MoreUtils qw(any);
+use Path::Tiny;
 
 use Lintian::Data;
 use Lintian::Relation ();
@@ -44,8 +45,8 @@ use Lintian::SlidingWindow;
 # not less than 8192 for source missing
 use constant BLOCKSIZE => 16_384;
 
-# constant for insane line length
-use constant INSANE_LINE_LENGTH => 512;
+# constant for very long line lengths
+use constant VERY_LONG_LINE_LENGTH => 512;
 use constant SAFE_LINE_LENGTH => 256;
 
 use Moo;
@@ -353,36 +354,36 @@ our @TRAILING_WHITESPACE_FILES = (
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $d_files = $info->index_resolved_path('debian/files');
+    my $d_files = $processable->index_resolved_path('debian/files');
 
     if ($d_files and $d_files->is_file and $d_files->size != 0) {
         $self->tag('debian-files-list-in-source');
     }
 
     $self->tag('package-uses-deprecated-source-override-location')
-      if $info->index_resolved_path('debian/source.lintian-overrides');
+      if $processable->index_resolved_path('debian/source.lintian-overrides');
 
     # Check if the package build-depends on autotools-dev, automake,
     # or libtool.
-    my $ltinbd  = $info->relation('build-depends-all')->implies($LIBTOOL);
+    my $ltinbd= $processable->relation('build-depends-all')->implies($LIBTOOL);
     my %warned;
     # Assume the package to be non-native if the field is not present.
     # - while 1.0 is more likely in this case, Lintian will probably get
     #   better results by checking debfiles/ rather than looking for a diffstat
     #   that may not be present.
-    my $format = $info->field('format', '3.0 (quilt)');
+    my $format = $processable->field('format', '3.0 (quilt)');
 
     if ($format =~ /^\s*2\.0\s*\z/ or $format =~ /^\s*3\.0\s*\(quilt|git\)/) {
         $self->check_debian_dir(\%warned);
-    }elsif (not $info->native) {
+    }elsif (not $processable->native) {
         $self->check_diffstat(\%warned);
     }
     $self->find_cruft(\%warned, $ltinbd);
 
     for my $file (@EOL_TERMINATORS_FILES) {
-        my $path = $info->index_resolved_path("debian/$file");
+        my $path = $processable->index_resolved_path("debian/$file");
         next if not $path or not $path->is_open_ok;
         my $fd = $path->open;
         while (my $line = <$fd>) {
@@ -395,7 +396,7 @@ sub source {
     }
 
     for my $file (@TRAILING_WHITESPACE_FILES) {
-        my $path = $info->index_resolved_path($file->[0]);
+        my $path = $processable->index_resolved_path($file->[0]);
         next if not $path or not $path->is_open_ok;
         my $fd = $path->open;
         my @empty_lines;
@@ -415,11 +416,12 @@ sub source {
         }
     }
 
-    if (my $pycompat = $info->index_resolved_path('debian/pycompat')) {
+    if (my $pycompat = $processable->index_resolved_path('debian/pycompat')) {
         $self->tag('debian-pycompat-is-obsolete') if $pycompat->is_file;
     }
 
-    if (my $pyversions = $info->index_resolved_path('debian/pyversions')) {
+    if (my $pyversions= $processable->index_resolved_path('debian/pyversions'))
+    {
         $self->tag('debian-pyversions-is-obsolete') if $pyversions->is_file;
     }
 
@@ -427,7 +429,7 @@ sub source {
     # package if it isn't just tar cruft.
     for my $file (keys %ERRORS) {
         my $tag  = $ERRORS{$file};
-        my $path = $info->lab_data_path($file);
+        my $path = path($processable->groupdir)->child($file)->stringify;
         if (-s $path) {
             open(my $fd, '<', $path);
             local $_;
@@ -453,12 +455,6 @@ sub source {
         }
     }
 
-    foreach my $file ($info->sorted_orig_index) {
-        $self->tag('source-contains-empty-directory', $file)
-          if $file->is_dir
-          and scalar($file->children) == 0;
-    }
-
     return;
 }    # </run>
 
@@ -471,7 +467,7 @@ sub check_diffstat {
     my ($self, $warned) = @_;
 
     my $saw_file;
-    open(my $fd, '<', $self->info->diffstat);
+    open(my $fd, '<', $self->processable->diffstat);
     local $_;
     while (<$fd>) {
         my ($file) = (m,^\s+(.*?)\s+\|,)
@@ -533,9 +529,9 @@ sub check_diffstat {
 sub check_debian_dir {
     my ($self, $warned) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $droot = $info->index_resolved_path('debian/');
+    my $droot = $processable->index_resolved_path('debian/');
     return if not $droot;
 
     my @worklist = $droot->children;
@@ -597,14 +593,14 @@ sub istestset {
 sub find_cruft {
     my ($self, $warned, $ltinbd) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $prefix = ($info->native ? 'diff-contains' : 'source-contains');
+    my $prefix = ($processable->native ? 'diff-contains' : 'source-contains');
     my @worklist;
     my $ships_examples = _ships_examples($self->group);
 
     # start with the top-level dirs
-    push(@worklist, $info->index('')->children);
+    push(@worklist, $processable->index('')->children);
 
   ENTRY:
     while (my $entry = shift(@worklist)) {
@@ -665,10 +661,10 @@ sub find_cruft {
         next ENTRY unless $entry->is_file;
         # avoid lintian testset
         next ENTRY
-          if $self->processable->pkg_src eq 'lintian' && $istestsetdir;
+          if $self->processable->source eq 'lintian' && $istestsetdir;
 
         # check non free file
-        my $md5sum = $info->md5sums->{$name};
+        my $md5sum = $processable->md5sums->{$name};
         if(
             $self->md5sum_based_check(
                 $name, $md5sum, $NON_DISTRIBUTABLE_FILES,
@@ -677,7 +673,7 @@ sub find_cruft {
         ) {
             next ENTRY;
         }
-        unless ($info->is_non_free) {
+        unless ($processable->is_non_free) {
             $self->md5sum_based_check($name, $md5sum, $NON_FREE_FILES,
                 'license-problem-md5sum-non-free-file');
         }
@@ -718,7 +714,7 @@ sub find_cruft {
             && $entry->is_file
             && $entry->is_open_ok
             && $file_info =~ /gzip compressed data/
-            && !$info->index_resolved_path('debian/README.source')) {
+            && !$processable->index_resolved_path('debian/README.source')) {
             my $fd = $entry->open_gz;
             read($fd, my $magic, 4);
             close($fd);
@@ -824,11 +820,11 @@ sub find_cruft {
 
         $self->tag('source-contains-prebuilt-doxygen-documentation', $dirname)
           if $basename =~ m{^doxygen.(?:png|sty)$}
-          and $self->processable->pkg_src ne 'doxygen';
+          and $self->processable->source ne 'doxygen';
 
         unless ($warned->{$name}) {
             for my $rule (@file_checks) {
-                next if ($rule->[2] and not $info->native);
+                next if ($rule->[2] and not $processable->native);
                 if ($basename =~ /$rule->[0]/) {
                     $self->tag("${prefix}-$rule->[1]", $name);
                 }
@@ -869,13 +865,13 @@ sub check_missing_source {
         $extratext)
       = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     my $basename_of_dirname = basename($dirname);
     $extratext //= '';
 
     # do not check missing source for non free
-    if($info->is_non_free) {
+    if($processable->is_non_free) {
         return;
     }
 
@@ -891,7 +887,7 @@ sub check_missing_source {
     # As a special-case, check debian/missing-sources including symlinks, etc.
     foreach my $ext (($file, $basename)) {
         my $path = normalize_pkg_path("debian/missing-sources/$ext");
-        return if $path and $info->index_resolved_path($path);
+        return if $path and $processable->index_resolved_path($path);
     }
 
     # try to find for each replacement
@@ -940,7 +936,7 @@ sub check_missing_source {
                 next PATH;
             }
             # found source file or directory
-            if($info->index_resolved_path($newpath)) {
+            if($processable->index_resolved_path($newpath)) {
                 return;
             }
         }
@@ -955,7 +951,7 @@ sub check_missing_source {
 sub full_text_check {
     my ($self, $entry, $name, $basename, $dirname) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     # license string in debian/changelog are probably just change
     # Ignore these strings in d/README.{Debian,source}.  If they
@@ -1005,7 +1001,7 @@ sub full_text_check {
 
         # Skip the rest of the license checks for non-free
         # sections.
-        if ($info->is_non_free) {
+        if ($processable->is_non_free) {
             next BLOCK;
         }
 
@@ -1089,8 +1085,6 @@ sub check_html_cruft {
 sub check_js_script {
     my ($self, $entry, $name,$basename,$dirname,$lcscript) = @_;
 
-    my $info = $self->info;
-
     my $firstline = '';
     foreach (split /\n/, $lcscript) {
         if ($_ =~ m/^\s*$/) {
@@ -1124,8 +1118,6 @@ sub _is_javascript_but_not_minified {
 sub search_in_block0 {
     my ($self, $entry, $name, $basename, $dirname, $block) = @_;
 
-    my $info = $self->info;
-
     if(_is_javascript_but_not_minified($name)) {
         # exception sphinx documentation
         if($basename eq 'searchindex.js') {
@@ -1194,8 +1186,6 @@ sub search_in_block0 {
 sub warn_prebuilt_javascript{
     my ($self, $entry, $name, $basename, $dirname,$linelength,$cutoff) = @_;
 
-    my $info = $self->info;
-
     my $extratext
       =  'line length is '.int($linelength)." characters (>$cutoff)";
     $self->tag('source-contains-prebuilt-javascript-object',$name,$extratext);
@@ -1253,8 +1243,6 @@ sub _strip_c_comments {
 sub detect_browserify {
     my ($self, $entry, $name, $basename, $dirname, $block) = @_;
 
-    my $info = $self->info;
-
     $block =~ s,\n, ,msg;
     foreach my $browserifyregex ($BROWSERIFY_REGEX->all) {
         my $regex = $BROWSERIFY_REGEX->value($browserifyregex);
@@ -1272,20 +1260,18 @@ sub detect_browserify {
 sub linelength_test {
     my ($self, $entry, $name, $basename, $dirname, $block) = @_;
 
-    my $info = $self->info;
-
     my $linelength = 0;
     my $line;
     my $nextblock;
 
-    ($linelength)= _linelength_test_maxlength($block,INSANE_LINE_LENGTH);
-    # first check if line >  INSANE_LINE_LENGTH that is likely minification
+    ($linelength)= _linelength_test_maxlength($block,VERY_LONG_LINE_LENGTH);
+    # first check if line >  VERY_LONG_LINE_LENGTH that is likely minification
     # avoid problem by recursive regex with longline
     if($linelength) {
         $self->tag(
-            'insane-line-length-in-source-file',
+            'very-long-line-length-in-source-file',
             $name,'line length is',
-            int($linelength),'characters (>'.INSANE_LINE_LENGTH.')'
+            int($linelength),'characters (>'.VERY_LONG_LINE_LENGTH.')'
         );
         # clean up jslint craps line
         $block =~ s,^\s*/[*][^\n]*[*]/\s*$,,gm;
@@ -1308,12 +1294,13 @@ sub linelength_test {
         # detect browserification
         $self->detect_browserify($entry, $name, $basename, $dirname, $block);
 
-        # retry insane line length test now: if insane length likely minified
-        ($linelength)= _linelength_test_maxlength($block,INSANE_LINE_LENGTH);
+        # retry very long line length test now: likely minified
+        ($linelength)
+          = _linelength_test_maxlength($block,VERY_LONG_LINE_LENGTH);
 
         if($linelength) {
             $self->warn_prebuilt_javascript($entry, $name, $basename,
-                $dirname,$linelength,INSANE_LINE_LENGTH);
+                $dirname,$linelength,VERY_LONG_LINE_LENGTH);
             return 1;
         }
     }
@@ -1365,8 +1352,6 @@ sub check_gfdl_license_problem {
         %matchedhash
     )= @_;
 
-    my $info = $self->info;
-
     my $rawgfdlsections  = $matchedhash{rawgfdlsections}  || '';
     my $rawcontextbefore = $matchedhash{rawcontextbefore} || '';
 
@@ -1481,8 +1466,6 @@ sub rfc_whitelist_filename {
         %matchedhash
     )= @_;
 
-    my $info = $self->info;
-
     return 0 if $name eq 'debian/copyright';
     my $lcname = lc($basename);
 
@@ -1505,16 +1488,16 @@ sub php_source_whitelist {
         %matchedhash
     )= @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $copyright_path = $info->index_resolved_path('debian/copyright');
+    my $copyright_path = $processable->index_resolved_path('debian/copyright');
     if (    $copyright_path
         and $copyright_path->file_contents
         =~ m{^Source: https?://pecl.php.net/package/.*$}m) {
         return 0;
     }
 
-    if($self->processable->pkg_src =~ m,^php\d*(?:\.\d+)?$,xms) {
+    if($self->processable->source =~ m,^php\d*(?:\.\d+)?$,xms) {
         return 0;
     }
     $self->tag($licenseproblem, $name);
@@ -1680,12 +1663,10 @@ sub license_check {
         $cleanedblock,$matchedkeyword,$licenseproblemhash
     )= @_;
 
-    my $info = $self->info;
-
     my $ret = 0;
 
     # avoid to check lintian
-    if($self->processable->pkg_src eq 'lintian') {
+    if($self->processable->source eq 'lintian') {
         return $ret;
     }
   LICENSE:
@@ -1761,10 +1742,10 @@ sub _ships_examples {
     my @procs = $group->get_processables('binary');
     return 1 if not @procs;
     foreach my $binpkg (@procs) {
-        my $name = $binpkg->pkg_name;
+        my $name = $binpkg->name;
         # If we have an -examples package, assume we ship examples.
         return 1 if $name =~ m{-examples$};
-        my @files = $binpkg->info->sorted_index;
+        my @files = $binpkg->sorted_index;
         # Check each package for a directory (or symlink) called "examples".
         return 1
           if any { m{^usr/share/doc/(.+/)?examples/?$} } @files;
