@@ -98,6 +98,7 @@ sub binary {
     }
 
     $self->check_maintainer_scripts();
+    $self->check_systemd_socket_files();
 
     return;
 }
@@ -311,8 +312,8 @@ sub check_systemd_service_file {
         my @pidfile
           = $self->extract_service_file_values($file,'Service','PIDFile',1);
         foreach my $x (@pidfile) {
-            $self->tag('systemd-service-file-pidfile-refers-to-var-run',
-                $file, $x)
+            $self->tag('systemd-service-file-refers-to-var-run',
+                $file, 'PIDFile', $x)
               if $x =~ m,^/var/run/,;
         }
         my $seen_hardening;
@@ -486,6 +487,25 @@ sub check_maintainer_scripts {
     return;
 }
 
+sub check_systemd_socket_files {
+    my ($self) = @_;
+
+    my @files = $self->processable->sorted_index;
+
+    foreach my $file (grep { m,/systemd/system/.*\.socket$, } @files) {
+        my @xs
+          = $self->extract_service_file_values($file,'Socket','ListenStream',
+            1);
+        foreach my $x (@xs) {
+            $self->tag('systemd-service-file-refers-to-var-run',
+                $file, 'ListenStream', $x)
+              if $x =~ m,^/var/run/,;
+        }
+    }
+
+    return;
+}
+
 1;
 
 # Local Variables:
