@@ -24,8 +24,9 @@ use strict;
 use warnings;
 
 use Moo;
+use namespace::clean;
 
-with('Lintian::Check');
+with 'Lintian::Check';
 
 # Check /lib/udev/rules.d/, detect use of MODE="0666" and use of
 # GROUP="plugdev" without TAG+="uaccess".
@@ -35,11 +36,10 @@ sub binary {
 
     my $pkg = $self->package;
     my $type = $self->type;
-    my $info = $self->info;
-    my $proc = $self->processable;
+    my $processable = $self->processable;
     my $group = $self->group;
 
-    my $rules_dir = $info->index_resolved_path('lib/udev/rules.d/');
+    my $rules_dir = $processable->index_resolved_path('lib/udev/rules.d/');
     return unless $rules_dir;
     foreach my $file ($rules_dir->children) {
         if (!$file->is_open_ok) {
